==> tipfy.ext.jinja2-0.5.8.zip: tipfy.ext.jinja2-0.5.8/setup.py <==
"""
tipfy.ext.jinja2
================

This extension provides Jinja2 support for tipfy, the almighty little framework
for Google App Engine.

Links
-----
* `Tipfy's website <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.jinja2',
    version = '0.5.8',
    license = 'BSD',
    url = 'http://www.tipfy.org/',
    description = 'Jinja2 extension for tipfy',
    long_description=__doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms='any',
    packages = [
        'tipfy',
        'tipfy.ext',
        'tipfy.ext.jinja2',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data=True,
    install_requires = [
        'tipfy',
        'jinja2',
    ],
    entry_points = {
        'console_scripts': [
            'jinja2_compile = tipfy.ext.jinja2.scripts:compile_templates',
        ],
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> tipfy.ext.jinja2-0.6.zip: tipfy.ext.jinja2-0.6/setup.py <==
"""
tipfy.ext.jinja2
================

This extension provides Jinja2 support for tipfy.

Documentation is available at
`http://www.tipfy.org/wiki/extensions/jinja2/ <http://www.tipfy.org/wiki/extensions/jinja2/>`_.

Links
-----
* `Tipfy <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Source Code Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.jinja2',
    version = '0.6',
    license = 'BSD',
    url = 'http://www.tipfy.org/',
    description = 'Jinja2 extension for tipfy',
    long_description = __doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms = 'any',
    packages = [
        'tipfy',
        'tipfy.ext',
        'tipfy.ext.jinja2',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data = True,
    install_requires = [
        'tipfy',
        'jinja2',
    ],
    entry_points = {
        'console_scripts': [
            'jinja2_compile = tipfy.ext.jinja2.scripts:compile_templates',
        ],
    },
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
